﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint;
using System.Web.UI.WebControls;
using Microsoft.SharePoint.WebControls;
using Microsoft.SharePoint.Utilities;
using System.Globalization;
using System.Web;
using Microsoft.SharePoint.Administration;

namespace Dienstfahrten.Klassen
{
    public static class helper
    {

        public enum Seite
        {
            dienstfahrt,
            dienstfahrtListe,
            konfiguration
        };

        //##############################
        //Helper
        //##############################

        public static string validateTextBoxString(Label lblError, TextBox input, ref int _valiErrors)
        {
            if (input.Text == string.Empty)
            {
                lblError.Visible = true;
                _valiErrors++;
                return string.Empty;
            }
            else
            {
                return input.Text;
            }

        }

        public static int validateTextBoxInt(Label lblError, TextBox input, ref int _valiErrors)
        {
            int zahl = 0;
            try
            {
                zahl = int.Parse(input.Text);
                
                if (zahl == 0)
                {
                    lblError.Visible = true;
                    _valiErrors++;
                }
            }
            catch (Exception ex)
            {
                lblError.Visible = true;
                _valiErrors++;
            }
            return zahl;
        }


        public static Int64 validateTextBoxLongInt(Label lblError, TextBox input, ref int _valiErrors)
        {
            Int64 zahl = 0;
            try
            {
                zahl = Int64.Parse(input.Text);

                if (zahl == 0)
                {
                    lblError.Visible = true;
                    _valiErrors++;
                }
            }
            catch (Exception ex)
            {
                lblError.Visible = true;
                _valiErrors++;
            }
            return zahl;
        }


        //http://blog.qumsieh.ca/2008/07/21/how-to-use-the-people-editor-control-inside-sharepoint/
        public static SPUser validateTextBoxUser(Label lblError, PeopleEditor input, SPWeb web, ref int _valiErrors)
        {
            char[] splitter = { ',' };
            string[] splitPPData;

            SPUser user = null;
            if (input.IsValid)
            {
                splitPPData = input.CommaSeparatedAccounts.Split(splitter);

                // this collection will store the user values from the people editor which we'll eventually use to populate the field in the list
                SPFieldUserValueCollection values = new SPFieldUserValueCollection();

                // for each item in our array, create a new sp user object given the loginname and add to our collection
                try
                {
                    for (int i = 0; i < splitPPData.Length; i++)
                    {
                        string loginName = splitPPData[i];

                        if (!string.IsNullOrEmpty(loginName))
                        {
                            //user = web.SiteUsers[loginName];
                            user = web.EnsureUser(loginName); 
                            // you could also use SPUser user = web.EnsureUser(loginName); 
                            //SPFieldUserValue fuv = new SPFieldUserValue(currentWeb, user.ID, user.LoginName);
                        }
                    }

                    if (user == null)
                    {
                        lblError.Visible = true;
                        _valiErrors++;
                        user = null;
                    }
                }
                catch (Exception ex)
                {
                    lblError.Visible = true;
                    _valiErrors++;
                    user = null;
                }
            }
            else
            {
                lblError.Visible = true;
                _valiErrors++;
                user = null;
            }

            return user;
        }


        public static string GetLocalizedString(string key)
        {
            //string retStr = SPUtility.GetLocalizedString("$Resources:key", "test", (uint)CultureInfo.CurrentUICulture.LCID);
            //return retStr;
            try
            {
                //HttpContext.GetGlobalResourceObject("dienstfahrt", key).ToString();
                string retStr = HttpContext.GetGlobalResourceObject("dienstfahrt", key, CultureInfo.CurrentCulture).ToString();
                return retStr; 
            }
            catch
            {
                return key;
            }

        }

        public static SPUser getSPUserFromField(String fieldName, SPListItem spListItem)
        {
            SPUser spUser = null;
            try
            {
                if (fieldName != string.Empty)
                {
                    SPFieldUser field = spListItem.Fields[fieldName] as SPFieldUser;
                    if (field != null && spListItem[fieldName] != null)
                    {
                        SPFieldUserValue fieldValue = field.GetFieldValue(spListItem[fieldName].ToString()) as SPFieldUserValue;
                        if (fieldValue != null)
                        {
                            spUser = fieldValue.User;
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                throw ex;
            }
            return spUser;
        }

        public static SPUser getSPUserFromFieldId(Guid fieldId, SPListItem spListItem)
        {
            SPUser spUser = null;
            try
            {
                if (fieldId != Guid.Empty)
                {
                    SPFieldUser field = spListItem.Fields[fieldId] as SPFieldUser;
                    if (field != null && spListItem[fieldId] != null)
                    {
                        SPFieldUserValue fieldValue = field.GetFieldValue(spListItem[fieldId].ToString()) as SPFieldUserValue;
                        if (fieldValue != null)
                        {
                            spUser = fieldValue.User;
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                throw ex;
            }
            return spUser;
        }


        /// <summary>
        /// Berechne die Summe der gefahrenen KM
        /// </summary>
        /// <param name="df"></param>
        public static string berechneSummeDienstfahrtenKM(List<Object> df)
        {
            int summe = 0;
            foreach (Dienstfahrt item in df)
                summe += item.Gesamt;
            return summe.ToString();
        }

        /// <summary>
        /// Ermittelt Version und Modus von SharePoint und gibt Layoutspfadergänzung zurück
        /// </summary>
        /// <returns>Layoutspfad je nach SharePoinversion</returns>
        public static string getSharePointVersionPath(){
            string SPversionPath = string.Empty;
            
            //Ermittle Serverversion, 14=SP2010, 15=SP2013
            if(SPFarm.Local.BuildVersion.Major >= 15)
            {
                //1=2001, 2=2003, 3=2007, 4=2010, 5=2013
                if (SPContext.Current.Web.UIVersion == 4)
                    SPversionPath = "14/";
                else
                    SPversionPath = "15/";
            }

            return SPversionPath;
        }

        public static string getSharePointVersionControltemplatePath(string path) {
            return @"~/_CONTROLTEMPLATES/" + getSharePointVersionPath() + path;
        }
    }
}
